Struct HeaderValue
pub struct HeaderValue {
inner: Bytes,
is_sensitive: bool,
}Expand description
Represents an HTTP header field value.
In practice, HTTP header field values are usually valid ASCII. However, the HTTP spec allows for a header value to contain opaque bytes as well. In this case, the header field value is not able to be represented as a string.
To handle this, the HeaderValue is usable as a type and can be compared
with strings and implements Debug. A to_str fn is provided that returns
an Err if the header value contains non visible ascii characters.
Fields
inner: Bytesis_sensitive: boolImplementations
impl HeaderValue
impl HeaderValue
pub const fn from_static(src: &'static str) -> HeaderValue
pub const fn from_static(src: &'static str) -> HeaderValue
Convert a static string to a HeaderValue.
This function will not perform any copying, however the string is checked to ensure that no invalid characters are present. Only visible ASCII characters (32-127) are permitted.
Panics
This function panics if the argument contains invalid header value characters.
Examples
let val = HeaderValue::from_static("hello");
assert_eq!(val, "hello");pub fn from_str(src: &str) -> Result<HeaderValue, InvalidHeaderValue>
pub fn from_str(src: &str) -> Result<HeaderValue, InvalidHeaderValue>
Attempt to convert a string to a HeaderValue.
If the argument contains invalid header value characters, an error is
returned. Only visible ASCII characters (32-127) are permitted. Use
from_bytes to create a HeaderValue that includes opaque octets
(128-255).
This function is intended to be replaced in the future by a TryFrom
implementation once the trait is stabilized in std.
Examples
let val = HeaderValue::from_str("hello").unwrap();
assert_eq!(val, "hello");An invalid value
let val = HeaderValue::from_str("\n");
assert!(val.is_err());pub fn from_name(name: HeaderName) -> HeaderValue
pub fn from_name(name: HeaderName) -> HeaderValue
Converts a HeaderName into a HeaderValue
Since every valid HeaderName is a valid HeaderValue this is done infallibly.
Examples
let val = HeaderValue::from_name(ACCEPT);
assert_eq!(val, HeaderValue::from_bytes(b"accept").unwrap());pub fn from_bytes(src: &[u8]) -> Result<HeaderValue, InvalidHeaderValue>
pub fn from_bytes(src: &[u8]) -> Result<HeaderValue, InvalidHeaderValue>
Attempt to convert a byte slice to a HeaderValue.
If the argument contains invalid header value bytes, an error is returned. Only byte values between 32 and 255 (inclusive) are permitted, excluding byte 127 (DEL).
This function is intended to be replaced in the future by a TryFrom
implementation once the trait is stabilized in std.
Examples
let val = HeaderValue::from_bytes(b"hello\xfa").unwrap();
assert_eq!(val, &b"hello\xfa"[..]);An invalid value
let val = HeaderValue::from_bytes(b"\n");
assert!(val.is_err());Attempt to convert a Bytes buffer to a HeaderValue.
This will try to prevent a copy if the type passed is the type used internally, and will copy the data if it is not.
Convert a Bytes directly into a HeaderValue without validating.
This function does NOT validate that illegal bytes are not contained within the buffer.
Panics
In a debug build this will panic if src is not valid UTF-8.
Safety
src must contain valid UTF-8. In a release build it is undefined
behaviour to call this with src that is not valid UTF-8.
pub fn to_str(&self) -> Result<&str, ToStrError>
pub fn to_str(&self) -> Result<&str, ToStrError>
Yields a &str slice if the HeaderValue only contains visible ASCII
chars.
This function will perform a scan of the header value, checking all the characters.
Examples
let val = HeaderValue::from_static("hello");
assert_eq!(val.to_str().unwrap(), "hello");pub fn len(&self) -> usize
pub fn len(&self) -> usize
Returns the length of self.
This length is in bytes.
Examples
let val = HeaderValue::from_static("hello");
assert_eq!(val.len(), 5);pub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> bool
Returns true if the HeaderValue has a length of zero bytes.
Examples
let val = HeaderValue::from_static("");
assert!(val.is_empty());
let val = HeaderValue::from_static("hello");
assert!(!val.is_empty());pub fn as_bytes(&self) -> &[u8] โ
pub fn as_bytes(&self) -> &[u8] โ
Converts a HeaderValue to a byte slice.
Examples
let val = HeaderValue::from_static("hello");
assert_eq!(val.as_bytes(), b"hello");pub fn set_sensitive(&mut self, val: bool)
pub fn set_sensitive(&mut self, val: bool)
Mark that the header value represents sensitive information.
Examples
let mut val = HeaderValue::from_static("my secret");
val.set_sensitive(true);
assert!(val.is_sensitive());
val.set_sensitive(false);
assert!(!val.is_sensitive());pub fn is_sensitive(&self) -> bool
pub fn is_sensitive(&self) -> bool
Returns true if the value represents sensitive data.
Sensitive data could represent passwords or other data that should not be stored on disk or in memory. By marking header values as sensitive, components using this crate can be instructed to treat them with special care for security reasons. For example, caches can avoid storing sensitive values, and HPACK encoders used by HTTP/2.0 implementations can choose not to compress them.
Additionally, sensitive values will be masked by the Debug
implementation of HeaderValue.
Note that sensitivity is not factored into equality or ordering.
Examples
let mut val = HeaderValue::from_static("my secret");
val.set_sensitive(true);
assert!(val.is_sensitive());
val.set_sensitive(false);
assert!(!val.is_sensitive());Trait Implementations
impl AsRef<[u8]> for HeaderValue
impl AsRef<[u8]> for HeaderValue
impl Clone for HeaderValue
impl Clone for HeaderValue
fn clone(&self) -> HeaderValue
fn clone(&self) -> HeaderValue
1.0.0 ยท Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreimpl Debug for HeaderValue
impl Debug for HeaderValue
impl<'a> From<&'a HeaderValue> for HeaderValue
impl<'a> From<&'a HeaderValue> for HeaderValue
fn from(t: &'a HeaderValue) -> HeaderValue
fn from(t: &'a HeaderValue) -> HeaderValue
impl From<HeaderName> for HeaderValue
impl From<HeaderName> for HeaderValue
fn from(h: HeaderName) -> HeaderValue
fn from(h: HeaderName) -> HeaderValue
impl From<HeaderValue> for AllowOrigin
impl From<HeaderValue> for AllowOrigin
fn from(val: HeaderValue) -> AllowOrigin
fn from(val: HeaderValue) -> AllowOrigin
impl From<i16> for HeaderValue
impl From<i16> for HeaderValue
fn from(num: i16) -> HeaderValue
fn from(num: i16) -> HeaderValue
impl From<i32> for HeaderValue
impl From<i32> for HeaderValue
fn from(num: i32) -> HeaderValue
fn from(num: i32) -> HeaderValue
impl From<i64> for HeaderValue
impl From<i64> for HeaderValue
fn from(num: i64) -> HeaderValue
fn from(num: i64) -> HeaderValue
impl From<isize> for HeaderValue
impl From<isize> for HeaderValue
fn from(num: isize) -> HeaderValue
fn from(num: isize) -> HeaderValue
impl From<u16> for HeaderValue
impl From<u16> for HeaderValue
fn from(num: u16) -> HeaderValue
fn from(num: u16) -> HeaderValue
impl From<u32> for HeaderValue
impl From<u32> for HeaderValue
fn from(num: u32) -> HeaderValue
fn from(num: u32) -> HeaderValue
impl From<u64> for HeaderValue
impl From<u64> for HeaderValue
fn from(num: u64) -> HeaderValue
fn from(num: u64) -> HeaderValue
impl From<usize> for HeaderValue
impl From<usize> for HeaderValue
fn from(num: usize) -> HeaderValue
fn from(num: usize) -> HeaderValue
impl FromStr for HeaderValue
impl FromStr for HeaderValue
type Err = InvalidHeaderValue
type Err = InvalidHeaderValue
fn from_str(s: &str) -> Result<HeaderValue, <HeaderValue as FromStr>::Err>
fn from_str(s: &str) -> Result<HeaderValue, <HeaderValue as FromStr>::Err>
s to return a value of this type. Read moreimpl Hash for HeaderValue
impl Hash for HeaderValue
impl Ord for HeaderValue
impl Ord for HeaderValue
fn cmp(&self, other: &HeaderValue) -> Ordering
fn cmp(&self, other: &HeaderValue) -> Ordering
1.21.0 ยท Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
impl<'a, T> PartialEq<&'a T> for HeaderValue
impl<'a, T> PartialEq<&'a T> for HeaderValue
impl PartialEq<[u8]> for HeaderValue
impl PartialEq<[u8]> for HeaderValue
impl<'a> PartialEq<HeaderValue> for &'a HeaderValue
impl<'a> PartialEq<HeaderValue> for &'a HeaderValue
impl<'a> PartialEq<HeaderValue> for &'a str
impl<'a> PartialEq<HeaderValue> for &'a str
impl PartialEq<HeaderValue> for [u8]
impl PartialEq<HeaderValue> for [u8]
impl PartialEq<HeaderValue> for String
impl PartialEq<HeaderValue> for String
impl PartialEq<HeaderValue> for str
impl PartialEq<HeaderValue> for str
impl PartialEq<String> for HeaderValue
impl PartialEq<String> for HeaderValue
impl PartialEq<str> for HeaderValue
impl PartialEq<str> for HeaderValue
impl PartialEq for HeaderValue
impl PartialEq for HeaderValue
impl<'a, T> PartialOrd<&'a T> for HeaderValue
impl<'a, T> PartialOrd<&'a T> for HeaderValue
impl PartialOrd<[u8]> for HeaderValue
impl PartialOrd<[u8]> for HeaderValue
impl<'a> PartialOrd<HeaderValue> for &'a HeaderValue
impl<'a> PartialOrd<HeaderValue> for &'a HeaderValue
impl<'a> PartialOrd<HeaderValue> for &'a str
impl<'a> PartialOrd<HeaderValue> for &'a str
impl PartialOrd<HeaderValue> for [u8]
impl PartialOrd<HeaderValue> for [u8]
impl PartialOrd<HeaderValue> for String
impl PartialOrd<HeaderValue> for String
impl PartialOrd<HeaderValue> for str
impl PartialOrd<HeaderValue> for str
impl PartialOrd<String> for HeaderValue
impl PartialOrd<String> for HeaderValue
impl PartialOrd<str> for HeaderValue
impl PartialOrd<str> for HeaderValue
impl PartialOrd for HeaderValue
impl PartialOrd for HeaderValue
impl<'a> TryFrom<&'a [u8]> for HeaderValue
impl<'a> TryFrom<&'a [u8]> for HeaderValue
type Error = InvalidHeaderValue
type Error = InvalidHeaderValue
fn try_from(
t: &'a [u8],
) -> Result<HeaderValue, <HeaderValue as TryFrom<&'a [u8]>>::Error>
fn try_from( t: &'a [u8], ) -> Result<HeaderValue, <HeaderValue as TryFrom<&'a [u8]>>::Error>
impl<'a> TryFrom<&'a String> for HeaderValue
impl<'a> TryFrom<&'a String> for HeaderValue
type Error = InvalidHeaderValue
type Error = InvalidHeaderValue
fn try_from(
s: &'a String,
) -> Result<HeaderValue, <HeaderValue as TryFrom<&'a String>>::Error>
fn try_from( s: &'a String, ) -> Result<HeaderValue, <HeaderValue as TryFrom<&'a String>>::Error>
impl<'a> TryFrom<&'a str> for HeaderValue
impl<'a> TryFrom<&'a str> for HeaderValue
type Error = InvalidHeaderValue
type Error = InvalidHeaderValue
fn try_from(
t: &'a str,
) -> Result<HeaderValue, <HeaderValue as TryFrom<&'a str>>::Error>
fn try_from( t: &'a str, ) -> Result<HeaderValue, <HeaderValue as TryFrom<&'a str>>::Error>
impl TryFrom<String> for HeaderValue
impl TryFrom<String> for HeaderValue
type Error = InvalidHeaderValue
type Error = InvalidHeaderValue
fn try_from(
t: String,
) -> Result<HeaderValue, <HeaderValue as TryFrom<String>>::Error>
fn try_from( t: String, ) -> Result<HeaderValue, <HeaderValue as TryFrom<String>>::Error>
impl TryFrom<Vec<u8>> for HeaderValue
impl TryFrom<Vec<u8>> for HeaderValue
type Error = InvalidHeaderValue
type Error = InvalidHeaderValue
impl Eq for HeaderValue